==> 0.0.6.tar.gz: android/src/main/java/com/example/attestr_flowx_plugin/AttestrFlowxDelegate.java <==
package com.example.attestr_flowx_plugin;

import android.app.Activity;
import android.text.TextUtils;

import androidx.annotation.NonNull;

import com.attestr.flowx.AttestrFlowx;
import com.attestr.flowx.listener.AttestrFlowXListener;

import java.util.HashMap;
import java.util.Map;

import io.flutter.embedding.android.FlutterActivity;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * Copyright (c) 2021 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Gaurav Naresh Pandit
 * @Since 30/05/22
 **/
public class AttestrFlowxDelegate extends FlutterActivity
        implements AttestrFlowXListener {

//    private Activity mActivity;
    private static final int FLOW_COMPLETE = 0;
    private static final int FLOW_SKIP = 1;
    private static final int FLOW_ERROR = 2;
    private final AttestrFlowx attestrFlowx = new AttestrFlowx();
    private Result pendingResult;

    public AttestrFlowxDelegate(){}

    public void initiateSession(@NonNull MethodCall call,
                                @NonNull Result result) {
        this.pendingResult = result;
        String handshakeID = call.argument("handshake_id");
        String client_key = call.argument("client_key");
        String locale = call.argument("locale");

        if (!TextUtils.isEmpty(handshakeID) && !TextUtils.isEmpty(client_key)) {
            attestrFlowx.init(client_key, handshakeID, this);
            attestrFlowx.launch(
                    locale,
                    true,
                    null
            );
        }
    }

    @Override
    public void onFlowXComplete(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_COMPLETE);

            Map<String, Object> data = new HashMap<>();
            data.put("message", map.get("signature"));

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }

    @Override
    public void onFlowXSkip(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_SKIP);

            Map<String, Object> data = new HashMap<>();
            data.put("message", "Flow skip");

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }

    @Override
    public void onFlowXError(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_ERROR);

            Map<String, Object> data = new HashMap<>();
            data.put("message", map.get("message"));

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }
}

==> 0.1.8.tar.gz: android/src/main/java/com/example/attestr_flowx_plugin/AttestrFlowxDelegate.java <==
package com.example.attestr_flowx_plugin;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.attestr.flowx.AttestrFlowx;
import com.attestr.flowx.listener.AttestrFlowXListener;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * Copyright (c) 2021 Pegadroid IQ Solutions Pvt. Ltd.
 *
 * @Author Gaurav Naresh Pandit
 * @Since 30/05/22
 **/
public class AttestrFlowxDelegate extends Activity
        implements AttestrFlowXListener {

    private static final int FLOW_COMPLETE = 0;
    private static final int FLOW_SKIP = 1;
    private static final int FLOW_ERROR = 2;
    private static final String TAG = "AttestrFlowxDelegate";
    private final AttestrFlowx attestrFlowx = new AttestrFlowx();
    private Result pendingResult;
    private Activity mActivity;

    public AttestrFlowxDelegate() {
        this.mActivity = this;
    }

    public void initiateSession(@NonNull MethodCall call,
                                @NonNull Result result) {
        this.pendingResult = result;
        String handshakeID = call.argument("handshake_id");
        String client_key = call.argument("client_key");
        String locale = call.argument("locale");

        if (mActivity != null) {
            if (!TextUtils.isEmpty(handshakeID) && !TextUtils.isEmpty(client_key)) {
                attestrFlowx.init(client_key, handshakeID, mActivity);
                attestrFlowx.launch(
                        locale,
                        true,
                        null
                );
            }
        } else {
            Log.d(TAG, "Activity Null");
        }
    }

    @Override
    public void onFlowXComplete(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_COMPLETE);

            Map<String, Object> data = new HashMap<>();
            data.put("message", map.get("signature"));

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }

    @Override
    public void onFlowXSkip(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_SKIP);

            Map<String, Object> data = new HashMap<>();
            data.put("message", "Flow skip");

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }

    @Override
    public void onFlowXError(Map<String, Object> map) {
        if (pendingResult != null) {
            Map<String, Object> reply = new HashMap<>();
            reply.put("type", FLOW_ERROR);

            Map<String, Object> data = new HashMap<>();
            data.put("message", map.get("message"));

            reply.put("data", data);

            pendingResult.success(reply);
        }
    }

}
